import { default as FRStep } from '../fr-auth/fr-step';
export type QRCodeData = {
    message: string;
    use: string;
    uri: string;
};
/**
 * @class FRQRCode - A utility class for handling QR Code steps
 *
 * Example:
 *
 * ```js
 * const isQRCodeStep = FRQRCode.isQRCodeStep(step);
 * let qrCodeData;
 * if (isQRCodeStep) {
 *   qrCodeData = FRQRCode.getQRCodeData(step);
 * }
 * ```
 */
declare abstract class FRQRCode {
    /**
     * @method isQRCodeStep - determines if step contains QR Code callbacks
     * @param {FRStep} step - step object from AM response
     * @returns {boolean}
     */
    static isQRCodeStep(step: FRStep): boolean;
    /**
     * @method getQRCodeData - gets the necessary information from the QR Code callbacks
     * @param {FRStep} step - step object from AM response
     * @returns {QRCodeData}
     */
    static getQRCodeData(step: FRStep): QRCodeData;
    private static getQRCodeURICb;
}
export default FRQRCode;
//# sourceMappingURL=index.d.ts.map